@@ -9,8 +9,16 @@
 //! [pqc]: https://github.com/pqclean/pqclean/
 //!
 
+#![no_std]
 #![allow(clippy::len_without_is_empty)]
 
+// For no-std vectors
+extern crate alloc;
+
+// For tests
+#[cfg(feature = "std")]
+extern crate std;
+
 pub mod falcon1024;
 pub mod falcon512;
 pub mod ffi;
